Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(333)

Unified Diff: net/proxy/proxy_script_fetcher.h

Issue 210028: Respect the charset specified in PAC file responses. ProxyScriptFetcher is no... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: re-order parameter so output is last Created 11 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/proxy/proxy_resolver_v8.cc ('k') | net/proxy/proxy_script_fetcher.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/proxy/proxy_script_fetcher.h
===================================================================
--- net/proxy/proxy_script_fetcher.h (revision 26789)
+++ net/proxy/proxy_script_fetcher.h (working copy)
@@ -26,9 +26,9 @@
// Downloads the given PAC URL, and invokes |callback| on completion.
// On success |callback| is executed with a result code of OK, and a
// string of the response bytes. On failure, the result bytes is an empty
// string, and the result code is a network error. Some special network
// errors that may occur are:
//
// ERR_TIMED_OUT -- the fetch took too long to complete.
// ERR_FILE_TOO_BIG -- the response's body was too large.
@@ -39,7 +39,7 @@
// deleting |this|), then no callback is invoked.
//
// Only one fetch is allowed to be outstanding at a time.
- virtual int Fetch(const GURL& url, std::string* bytes,
+ virtual int Fetch(const GURL& url, std::string* utf8_bytes,
CompletionCallback* callback) = 0;
// Aborts the in-progress fetch (if any).
« no previous file with comments | « net/proxy/proxy_resolver_v8.cc ('k') | net/proxy/proxy_script_fetcher.cc » ('j') | no next file with comments »
@@ -26,9 +26,9 @@
// Downloads the given PAC URL, and invokes |callback| on completion.
// On success |callback| is executed with a result code of OK, and a
- // string of the response bytes. On failure, the result bytes is an empty
- // string, and the result code is a network error. Some special network
- // errors that may occur are:
+ // string of the response bytes (as UTF8). On failure, the result bytes is
+ // an empty string, and the result code is a network error. Some special
+ // network errors that may occur are:
//
// ERR_TIMED_OUT -- the fetch took too long to complete.

Powered by Google App Engine
This is Rietveld 408576698